pub struct SessionAnalyzer { /* private fields */ }Expand description
Builder for analyzing sessions with multiple diagnostic checks.
Apply one or more diagnostics to a session to generate an analysis report with insights and a health score.
Implementations
Sourceimpl SessionAnalyzer
impl SessionAnalyzer
pub fn new(session: AgentSession) -> Self
Sourcepub fn check(self, diagnostic: Diagnostic) -> Self
pub fn check(self, diagnostic: Diagnostic) -> Self
Add a diagnostic check to the analysis.
pub fn report(self) -> Result<AnalysisReport>